Module: Decidim::Admin::ParticipatorySpace::Concerns::HasMembers

Extended by:
ActiveSupport::Concern
Defined in:
app/controllers/decidim/admin/participatory_space/concerns/has_members.rb

Overview

Members can be related to any ParticipatorySpace, in order to manage the members for a given type, you should create a new controller and include this concern.

It takes the current_participatory_space that is defined in the controller, so there is no need to define any method