Class: Decidim::Admin::ParticipatorySpace::CreateMember

Inherits:
Command
  • Object
show all
Defined in:
app/commands/decidim/admin/participatory_space/create_member.rb

Overview

A command with all the business logic when creating a new participatory space member in the system.

Instance Method Summary collapse

Constructor Details

#initialize(form, member_to, via_csv: false) ⇒ CreateMember

Public: Initializes the command.

form - A form object with the params. member_to - The member_to that will hold the

user role


15
16
17
18
19
# File 'app/commands/decidim/admin/participatory_space/create_member.rb', line 15

def initialize(form, member_to, via_csv: false)
  @form = form
  @member_to = member_to
  @via_csv = via_csv
end

Instance Method Details

#callObject

Executes the command. Broadcasts these events:

  • :ok when everything is valid.

  • :invalid if the form was not valid and we could not proceed.

Returns nothing.



27
28
29
30
31
32
33
34
35
36
37
38
39
# File 'app/commands/decidim/admin/participatory_space/create_member.rb', line 27

def call
  return broadcast(:invalid) if form.invalid?

  ActiveRecord::Base.transaction do
    @user ||= existing_user || new_user
    create_member
  end

  broadcast(:ok)
rescue ActiveRecord::RecordInvalid
  form.errors.add(:email, :taken)
  broadcast(:invalid)
end